==> jc-1.4.0.tar.gz: soot/jimple/parser/parser/ParserException.h <==
// public class soot.jimple.parser.parser.ParserException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 350479636530ccb1 soot_jimple_parser_parser_ParserException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_soot_jimple_parser_parser_ParserException_H_
#define _JC_soot_jimple_parser_parser_ParserException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Token$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_parser_ParserException$sub_refs	_jc_soot_jimple_parser_parser_ParserException$sub_refs;
typedef struct _jc_soot_jimple_parser_parser_ParserException$sub_nonrefs	_jc_soot_jimple_parser_parser_ParserException$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_parser_ParserException$refs	_jc_soot_jimple_parser_parser_ParserException$refs;
typedef struct _jc_soot_jimple_parser_parser_ParserException$nonrefs	_jc_soot_jimple_parser_parser_ParserException$nonrefs;
typedef struct _jc_soot_jimple_parser_parser_ParserException$object	_jc_soot_jimple_parser_parser_ParserException$object;

typedef const struct _jc_soot_jimple_parser_parser_ParserException$vmethods	_jc_soot_jimple_parser_parser_ParserException$vmethods;
typedef const struct _jc_soot_jimple_parser_parser_ParserException$vtable	_jc_soot_jimple_parser_parser_ParserException$vtable;
typedef const struct _jc_soot_jimple_parser_parser_ParserException$vtype	_jc_soot_jimple_parser_parser_ParserException$vtype;

// Constructors
extern void _jc_soot_jimple_parser_parser_ParserException$method$_init$97df421f1d5b7fa0(_jc_env *, struct _jc_soot_jimple_parser_parser_ParserException$object *, struct _jc_soot_jimple_parser_node_Token$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_soot_jimple_parser_node_Token$object *_jc_soot_jimple_parser_parser_ParserException$method$getToken$275e9105cf95ab28(_jc_env *, struct _jc_soot_jimple_parser_parser_ParserException$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_parser_ParserException$method_info$getToken$275e9105cf95ab28;

// Virtual methods structure
struct _jc_soot_jimple_parser_parser_ParserException$vmethods {
	struct _jc_soot_jimple_parser_node_Token$object	*(*getToken$275e9105cf95ab28)(_jc_env *, struct _jc_soot_jimple_parser_parser_ParserException$object *);
};

// Vtable
struct _jc_soot_jimple_parser_parser_ParserException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_soot_jimple_parser_parser_ParserException$vmethods	soot_jimple_parser_parser_ParserException;
};

// Vtype
struct _jc_soot_jimple_parser_parser_ParserException$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_parser_ParserException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_parser_ParserException$sub_refs {
	struct _jc_soot_jimple_parser_node_Token$object	*token;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_parser_ParserException$refs {
    _jc_soot_jimple_parser_parser_ParserException$sub_refs	soot_jimple_parser_parser_ParserException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_parser_ParserException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_parser_ParserException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_soot_jimple_parser_parser_ParserException$sub_nonrefs	soot_jimple_parser_parser_ParserException;
};

// Object instance structure
struct _jc_soot_jimple_parser_parser_ParserException$object {
	_jc_soot_jimple_parser_parser_ParserException$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_parser_ParserException$vtype	*vtype;
	_jc_soot_jimple_parser_parser_ParserException$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_parser_ParserException$vtype _jc_soot_jimple_parser_parser_ParserException$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_parser_ParserException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_parser_ParserException$class_object;

#endif	/* _JC_soot_jimple_parser_parser_ParserException_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/parser/ParserException.h <==
// public class soot.jimple.parser.parser.ParserException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 350479636530ccb1 soot_jimple_parser_parser_ParserException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_soot_jimple_parser_parser_ParserException_H_
#define _JC_soot_jimple_parser_parser_ParserException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Token$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_parser_ParserException$sub_refs	_jc_soot_jimple_parser_parser_ParserException$sub_refs;
typedef struct _jc_soot_jimple_parser_parser_ParserException$sub_nonrefs	_jc_soot_jimple_parser_parser_ParserException$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_parser_ParserException$refs	_jc_soot_jimple_parser_parser_ParserException$refs;
typedef struct _jc_soot_jimple_parser_parser_ParserException$nonrefs	_jc_soot_jimple_parser_parser_ParserException$nonrefs;
typedef struct _jc_soot_jimple_parser_parser_ParserException$object	_jc_soot_jimple_parser_parser_ParserException$object;

typedef const struct _jc_soot_jimple_parser_parser_ParserException$vmethods	_jc_soot_jimple_parser_parser_ParserException$vmethods;
typedef const struct _jc_soot_jimple_parser_parser_ParserException$vtable	_jc_soot_jimple_parser_parser_ParserException$vtable;
typedef const struct _jc_soot_jimple_parser_parser_ParserException$vtype	_jc_soot_jimple_parser_parser_ParserException$vtype;

// Constructors
extern void _jc_soot_jimple_parser_parser_ParserException$method$_init$97df421f1d5b7fa0(_jc_env *, struct _jc_soot_jimple_parser_parser_ParserException$object *, struct _jc_soot_jimple_parser_node_Token$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_soot_jimple_parser_node_Token$object *_jc_soot_jimple_parser_parser_ParserException$method$getToken$275e9105cf95ab28(_jc_env *, struct _jc_soot_jimple_parser_parser_ParserException$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_parser_ParserException$method_info$getToken$275e9105cf95ab28;

// Virtual methods structure
struct _jc_soot_jimple_parser_parser_ParserException$vmethods {
	struct _jc_soot_jimple_parser_node_Token$object	*(*getToken$275e9105cf95ab28)(_jc_env *, struct _jc_soot_jimple_parser_parser_ParserException$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_parser_ParserException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_soot_jimple_parser_parser_ParserException$vmethods	soot_jimple_parser_parser_ParserException;
};

// Vtype
struct _jc_soot_jimple_parser_parser_ParserException$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_parser_ParserException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_parser_ParserException$sub_refs {
	struct _jc_soot_jimple_parser_node_Token$object	*token;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_parser_ParserException$refs {
    _jc_soot_jimple_parser_parser_ParserException$sub_refs	soot_jimple_parser_parser_ParserException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_parser_ParserException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_parser_ParserException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_soot_jimple_parser_parser_ParserException$sub_nonrefs	soot_jimple_parser_parser_ParserException;
};

// Object instance structure
struct _jc_soot_jimple_parser_parser_ParserException$object {
	_jc_soot_jimple_parser_parser_ParserException$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_parser_ParserException$vtype	*vtype;
	_jc_soot_jimple_parser_parser_ParserException$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_parser_ParserException$vtype _jc_soot_jimple_parser_parser_ParserException$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_parser_ParserException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_parser_ParserException$class_object;

#endif	/* _JC_soot_jimple_parser_parser_ParserException_H_ */
